==> cms-db_v0.7.5.tar.gz: admin/settings.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('settings');
include('locale.inc.php');
$locale = new LocalizingClass('settings');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('desc_settings') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'anchormenu-mobile.css' : 'anchormenu.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<h2><?php locale('title_overview') ?></h2>
		<p>
			<a href="users.php?<?php echo SID ?>"><?php locale('desc_usersettings') ?></a><br />
			<a href="commonsettings.php?<?php echo SID ?>"><?php locale('desc_commonsettings') ?></a><br />
			<a href="url.php?<?php echo SID ?>"><?php locale('desc_urlsettings') ?></a><br />
			<a href="adminsettings.php?<?php echo SID ?>"><?php locale('desc_adminsettings') ?></a><br />
			<a href="locale.php?<?php echo SID ?>"><?php locale('desc_localesettings') ?></a>
		</p>

	</body>
</html>

==> cms-db_v0.7.9.tar.gz: admin/settings.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('settings');
include('locale.inc.php');
$locale = new LocalizingClass('settings');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('desc_settings') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<h2><?php locale('title_overview') ?></h2>
		<p>
			<a href="users.php?<?php echo SID ?>"><?php locale('desc_usersettings') ?></a><br />
			<a href="commonsettings.php?<?php echo SID ?>"><?php locale('desc_commonsettings') ?></a><br />
			<a href="url.php?<?php echo SID ?>"><?php locale('desc_urlsettings') ?></a><br />
			<a href="adminsettings.php?<?php echo SID ?>"><?php locale('desc_adminsettings') ?></a><br />
			<a href="locale.php?<?php echo SID ?>"><?php locale('desc_localesettings') ?></a>
		</p>

	</body>
</html>
